==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-connect/include/aws/connect/model/UpdateContactFlowContentRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/connect/Connect_EXPORTS.h>
#include <aws/connect/ConnectRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Connect
{
namespace Model
{

  /**
   */
  class AWS_CONNECT_API UpdateContactFlowContentRequest : public ConnectRequest
  {
  public:
    UpdateContactFlowContentRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "UpdateContactFlowContent"; }

    Aws::String SerializePayload() const override;


    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline const Aws::String& GetInstanceId() const{ return m_instanceId; }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline bool InstanceIdHasBeenSet() const { return m_instanceIdHasBeenSet; }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline void SetInstanceId(const Aws::String& value) { m_instanceIdHasBeenSet = true; m_instanceId = value; }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline void SetInstanceId(Aws::String&& value) { m_instanceIdHasBeenSet = true; m_instanceId = std::move(value); }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline void SetInstanceId(const char* value) { m_instanceIdHasBeenSet = true; m_instanceId.assign(value); }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline UpdateContactFlowContentRequest& WithInstanceId(const Aws::String& value) { SetInstanceId(value); return *this;}

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline UpdateContactFlowContentRequest& WithInstanceId(Aws::String&& value) { SetInstanceId(std::move(value)); return *this;}

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline UpdateContactFlowContentRequest& WithInstanceId(const char* value) { SetInstanceId(value); return *this;}


    /**
     * <p>The identifier of the flow.</p>
     */
    inline const Aws::String& GetContactFlowId() const{ return m_contactFlowId; }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline bool ContactFlowIdHasBeenSet() const { return m_contactFlowIdHasBeenSet; }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline void SetContactFlowId(const Aws::String& value) { m_contactFlowIdHasBeenSet = true; m_contactFlowId = value; }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline void SetContactFlowId(Aws::String&& value) { m_contactFlowIdHasBeenSet = true; m_contactFlowId = std::move(value); }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline void SetContactFlowId(const char* value) { m_contactFlowIdHasBeenSet = true; m_contactFlowId.assign(value); }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline UpdateContactFlowContentRequest& WithContactFlowId(const Aws::String& value) { SetContactFlowId(value); return *this;}

    /**
     * <p>The identifier of the flow.</p>
     */
    inline UpdateContactFlowContentRequest& WithContactFlowId(Aws::String&& value) { SetContactFlowId(std::move(value)); return *this;}

    /**
     * <p>The identifier of the flow.</p>
     */
    inline UpdateContactFlowContentRequest& WithContactFlowId(const char* value) { SetContactFlowId(value); return *this;}


    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline const Aws::String& GetContent() const{ return m_content; }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline bool ContentHasBeenSet() const { return m_contentHasBeenSet; }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline void SetContent(const Aws::String& value) { m_contentHasBeenSet = true; m_content = value; }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline void SetContent(Aws::String&& value) { m_contentHasBeenSet = true; m_content = std::move(value); }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline void SetContent(const char* value) { m_contentHasBeenSet = true; m_content.assign(value); }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline UpdateContactFlowContentRequest& WithContent(const Aws::String& value) { SetContent(value); return *this;}

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline UpdateContactFlowContentRequest& WithContent(Aws::String&& value) { SetContent(std::move(value)); return *this;}

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline UpdateContactFlowContentRequest& WithContent(const char* value) { SetContent(value); return *this;}

  private:

    Aws::String m_instanceId;
    bool m_instanceIdHasBeenSet = false;

    Aws::String m_contactFlowId;
    bool m_contactFlowIdHasBeenSet = false;

    Aws::String m_content;
    bool m_contentHasBeenSet = false;
  };

} // namespace Model
} // namespace Connect
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.26-1.src.tar.zst: aws-sdk-cpp-1.10.26/aws-cpp-sdk-connect/include/aws/connect/model/UpdateContactFlowContentRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/connect/Connect_EXPORTS.h>
#include <aws/connect/ConnectRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Connect
{
namespace Model
{

  /**
   */
  class UpdateContactFlowContentRequest : public ConnectRequest
  {
  public:
    AWS_CONNECT_API UpdateContactFlowContentRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "UpdateContactFlowContent"; }

    AWS_CONNECT_API Aws::String SerializePayload() const override;


    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline const Aws::String& GetInstanceId() const{ return m_instanceId; }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline bool InstanceIdHasBeenSet() const { return m_instanceIdHasBeenSet; }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline void SetInstanceId(const Aws::String& value) { m_instanceIdHasBeenSet = true; m_instanceId = value; }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline void SetInstanceId(Aws::String&& value) { m_instanceIdHasBeenSet = true; m_instanceId = std::move(value); }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline void SetInstanceId(const char* value) { m_instanceIdHasBeenSet = true; m_instanceId.assign(value); }

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline UpdateContactFlowContentRequest& WithInstanceId(const Aws::String& value) { SetInstanceId(value); return *this;}

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline UpdateContactFlowContentRequest& WithInstanceId(Aws::String&& value) { SetInstanceId(std::move(value)); return *this;}

    /**
     * <p>The identifier of the Amazon Connect instance.</p>
     */
    inline UpdateContactFlowContentRequest& WithInstanceId(const char* value) { SetInstanceId(value); return *this;}


    /**
     * <p>The identifier of the flow.</p>
     */
    inline const Aws::String& GetContactFlowId() const{ return m_contactFlowId; }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline bool ContactFlowIdHasBeenSet() const { return m_contactFlowIdHasBeenSet; }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline void SetContactFlowId(const Aws::String& value) { m_contactFlowIdHasBeenSet = true; m_contactFlowId = value; }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline void SetContactFlowId(Aws::String&& value) { m_contactFlowIdHasBeenSet = true; m_contactFlowId = std::move(value); }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline void SetContactFlowId(const char* value) { m_contactFlowIdHasBeenSet = true; m_contactFlowId.assign(value); }

    /**
     * <p>The identifier of the flow.</p>
     */
    inline UpdateContactFlowContentRequest& WithContactFlowId(const Aws::String& value) { SetContactFlowId(value); return *this;}

    /**
     * <p>The identifier of the flow.</p>
     */
    inline UpdateContactFlowContentRequest& WithContactFlowId(Aws::String&& value) { SetContactFlowId(std::move(value)); return *this;}

    /**
     * <p>The identifier of the flow.</p>
     */
    inline UpdateContactFlowContentRequest& WithContactFlowId(const char* value) { SetContactFlowId(value); return *this;}


    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline const Aws::String& GetContent() const{ return m_content; }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline bool ContentHasBeenSet() const { return m_contentHasBeenSet; }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline void SetContent(const Aws::String& value) { m_contentHasBeenSet = true; m_content = value; }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline void SetContent(Aws::String&& value) { m_contentHasBeenSet = true; m_content = std::move(value); }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline void SetContent(const char* value) { m_contentHasBeenSet = true; m_content.assign(value); }

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline UpdateContactFlowContentRequest& WithContent(const Aws::String& value) { SetContent(value); return *this;}

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline UpdateContactFlowContentRequest& WithContent(Aws::String&& value) { SetContent(std::move(value)); return *this;}

    /**
     * <p>The JSON string that represents flow's content. For an example, see <a
     * href="https://docs.aws.amazon.com/connect/latest/adminguide/flow-language-example.html">Example
     * contact flow in Amazon Connect Flow language</a> in the <i>Amazon Connect
     * Administrator Guide</i>. </p>
     */
    inline UpdateContactFlowContentRequest& WithContent(const char* value) { SetContent(value); return *this;}

  private:

    Aws::String m_instanceId;
    bool m_instanceIdHasBeenSet = false;

    Aws::String m_contactFlowId;
    bool m_contactFlowIdHasBeenSet = false;

    Aws::String m_content;
    bool m_contentHasBeenSet = false;
  };

} // namespace Model
} // namespace Connect
} // namespace Aws
